@import url('https://fonts.googleapis.com/css?family=Roboto');

body {
    display: flex;
    min-height: 100vh;
    flex-direction: column;
}

main {
     flex: 1 0 auto;
}

.tabs { 
    /* Materialize has a bug that shows the scrollbar sometimes, this prevents it */
    /*overflow-x: hidden;*/
}

td, tr {
    padding-right: 1px;
    padding-left: 1px;
    min-width: 60px;
}

.tight td {
    padding: 3px 3px;
}

.tighter {
    padding: 1px 1px;
}

.text-small {
    font-size: .75em;
}

.text-normal {
    font-size: 1em;
}

.text-right {
    text-align: right;
}

.text-center {
    text-align: center;
}

.info {
    color: red;
}

.single-line {
    white-space: nowrap;
}

.responsive-table-wrapper {
    overflow-x: auto;
    min-width: 100%;
    max-width: 110%;
    margin: 0 -5%;
}

.push-footer {
    min-height: 100vh;
}

.autocomplete-content {
    opacity: .8;
    position: absolute;
    width: 100%;
}

.hidden {
    display: none;
}

.cell-collapsed {
    /* background: grey; */
    background-color: #f2f2f2;
}