# Generated by Django 2.1.1 on 2018-09-08 21:51

from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        ('bom', '0001_initial'),
    ]

    operations = [
        migrations.AlterField(
            model_name='subpart',
            name='assembly_part',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='assembly_part', to='bom.Part'),
        ),
        migrations.AlterField(
            model_name='subpart',
            name='assembly_subpart',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='assembly_subpart', to='bom.Part'),
        ),
    ]
